@@ -2,6 +2,12 @@ import os
 import sys
 
 
+class UIOpenMode:
+    NONE = 0
+    CHROME = 1
+    USER_DEFAULT = 2
+
+
 # Temporary directory for packaging scripts to speed up consecutive builds. Created on application start.
 temporary_directory = None
 
@@ -13,6 +19,6 @@ DEFAULT_RECURSION_LIMIT = sys.getrecursionlimit()
 
 # Argument-influenced configuration
 package_filename = None
-disable_chrome = False
+ui_open_mode = UIOpenMode.CHROME
 supplied_ui_configuration = None
 default_output_directory = os.path.abspath('output')
